@@ -8,15 +8,19 @@ del sys
 main_path = os.path.dirname(os.path.abspath(__file__))
 del os
 
-from .log import config_path, log, log_paifu, log_parser, remove_old_paifu
-from .paifu_dl import paifu_dl
-from .src.get_paifu import get_paifu
-from .src.i18n import localized_str
 from .version import __version__
 
+from .log import config_path, log, log_paifu, log_parser, remove_old_paifu
+from .paifu_dl import paifu_dl
+from .src.get_paifu import get_paifu, get_paifu_from_client_log, get_paifu_from_local
+from .src.i18n import localized_str
+
 __all__ = [
+    "__version__",
     "config_path",
     "get_paifu",
+    "get_paifu_from_client_log",
+    "get_paifu_from_local",
     "localized_str",
     "log",
     "log_paifu",
@@ -24,5 +28,4 @@ __all__ = [
     "main_path",
     "remove_old_paifu",
     "paifu_dl",
-    "__version__",
 ]
